﻿using System;
using System.Windows.Forms;
using System.Windows.Forms.DataVisualization.Charting;
using Display;


class Fourier
{
    const int samplerate = 128;                 // Abtastwerte im Abtastintervall
    const double PI =        3.141592653589793;
    const int    periods =   2;                 // Perioden insgesamt

    public double[] signal = new double[samplerate*periods];
    public double[] arg    = new double[samplerate*periods];

    public void CreateSignal(int select, int order)
    {
        // create rectangle data
        if (select == 1)
        {
            for (int i = 1; i <= order; i++)
            {
                for (int k = 0; k < samplerate*periods; k++)
                {
                    signal[k] += Math.Sin(2.0*PI*k*(2*i-1) / samplerate)
                                 /
                                 (2*i-1);
                }
            }
        }

        // create sawtooth data
        if (select == 2)
        {
            for (int i = 1; i <= order; i++)
            {
                for (int k = 0; k < samplerate*periods; k++)
                {
                    signal[k] += Math.Sin(2.0*PI*k*i / samplerate) / i;
                }
            }
        }

        // store argument data
        for (int k = 0; k < samplerate*periods; k++)
        {
            arg[k] = 2*PI*k/samplerate;
        }
    }
}

class Execute
{
    [STAThread]
    static void Main()
    {
        string userinput = "";
        int select = 0;
        int order = 1;

        Console.Write("Please select signal:\n\n");
        Console.Write("Rectangle  ->  1\n");
        Console.Write("Sawtooth   ->  2\n");
        Console.WriteLine();
        userinput = Console.ReadLine();
        select = Convert.ToInt32(userinput);

        while (order > 0)
        {
            Console.Write("order of Fourier series: ");
            userinput = Console.ReadLine();
            order = Convert.ToInt32(userinput);

            // create data from fourier series
            Fourier myFourierObj = new Fourier();
            myFourierObj.CreateSignal(select, order);

            // create a chart for displaying that data...
            DisplayChart mydisplay = new DisplayChart(720, 480, SeriesChartType.Line, "Fourier-Reihe", "t", "signal(t)");
            mydisplay.AddData(myFourierObj.arg, myFourierObj.signal);

            // ...and run the chart-application
            Application.EnableVisualStyles();
            Application.Run(mydisplay);
            mydisplay.Dispose();
            Application.Exit();
        }
    }
}
